// Package har provides the Chrome DevTools Protocol
// commands, types, and events for the HAR domain.
//
// HTTP Archive Format.
//
// Generated by the cdproto-gen command.
package har

// Code generated by cdproto-gen. DO NOT EDIT.
